import request from '@/utils/request'
// 考试人员-删除
export function examUserWhitelistDel(examUserWhitelistId) {
  return request({
    url: '/admin/examUserWhitelist/delete',
    method: 'get',
    params: { examUserWhitelistId }
  })
}
// 考试人员-一键删除
export function examUserWhitelistDeleteAll(params) {
  return request({
    url: '/admin/examUserWhitelist/deleteAll',
    method: 'get',
    params
  })
}
// 考试人员-分页
export function examUserWhitelist(data) {
  return request({
    url: '/admin/examUserWhitelist/getPageList',
    method: 'post',
    data: data
  })
}
// 考试人员-新增
export function examUserWhitelistInsert(data) {
  return request({
    url: '/admin/examUserWhitelist/insert',
    method: 'post',
    data: data
  })
}
// 考试人员-批量导入
export function uploadExcel(data) {
  return request({
    url: '/admin/examUserWhitelist/uploadExcel',
    method: 'post',
    data,
  })
}
// 考试人员-导出
export function excelOut(data) {
  return request({
    url: '/admin/examUserWhitelist/excelOut',
    method: 'post',
    responseType: 'blob',
    data: data
  })
}
